#
# spec file for package frogr
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           frogr
Version:        0.11
Release:        6.2
Summary:        Tool to Manage Flickr Accounts
License:        GPL-3.0
Group:          Productivity/Graphics/Other
Url:            https://live.gnome.org/Frogr
Source:         http://download.gnome.org/sources/frogr/%{version}/%{name}-%{version}.tar.xz
BuildRequires:  intltool
BuildRequires:  itstool
BuildRequires:  libgcrypt-devel >= 1.5.0
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(glib-2.0) >= 2.32
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.0
BuildRequires:  pkgconfig(json-glib-1.0) >= 0.12
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libsoup-2.4) >= 2.34
BuildRequires:  pkgconfig(libxml-2.0)
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Frogr is a small application for the GNOME desktop that allows users to
manage their accounts in the Flickr image hosting website. It supports
all the basic Flickr features, including uploading pictures, adding
descriptions, setting tags and managing sets and groups pools.

%lang_package
%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file frogr Viewer

%clean
%{?buildroot:rm -rf %{buildroot}}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING NEWS README THANKS
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}
%dir %{_datadir}/appdata/
%{_datadir}/appdata/frogr.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}/
%{_datadir}/pixmaps/frogr.xpm
%{_datadir}/icons/HighContrast/
%{_datadir}/icons/hicolor/*/apps/frogr.*
%{_mandir}/man1/frogr.1%{ext_man}

%files lang -f %{name}.lang

%changelog
* Thu Jan  8 2015 dimstar@opensuse.org
- Update to version 0.11:
  + Moved to GtkHeaderBar plus a new menu button for GTK+ >= 3.12.
  + Added new option to replace "date posted" with "date taken" for
    new uploads.
  + Speeded up picture loading when the "import tags" feature is
    enabled.
  + Fixed random crashes due to missing initialization of the
    gcrypt library.
  + Fixed issue setting inconsistent state of toggle buttons for
    multiple pictures.
  + Removed deprecated usage of GtkAlignment and
    gtk_misc_set_padding().
  + Removed usage of deprecated icon names (use those from the Icon
    Naming Spec).
  + Normalized .doap file (added 'category' and
    'programming-language').
  + Set the minimum required version of gcrypt to 1.5.0.
  + Bugs fixed: bgo#732475, bgo#734193, bgo#734202, bgo#738863.
  + Updated translations.
* Tue Jul 29 2014 zaitor@opensuse.org
- Update to version 0.10:
  + Use SSL endpoints for the Flickr API.
  + Fixed issues with AppData (validation and installation).
  + Enable video uploads by default, but make it configurable.
  + Remove unsupported option from YELP_HELP_INIT.
  + Remove dependency on libsoup-gnome.
  + A few minor improvements and bug fixes.
  + Updated translations.
- Remove pkgconfig(gstreamer-0.10) BuildRequires for obsolete
  versions of openSUSE.
* Fri Jan 17 2014 zaitor@opensuse.org
- Update to version 0.9:
  + Ported to GStreamer 1.0 (0.10 still supported).
  + Provided a high contrast icon.
  + Switched to yelp-tools from gnome-doc-utils.
  + Redesign of the "Edit details" and "Settings" dialogs.
  + Added keywords to .desktop file.
  + Added an appdata.xml file for the GNOME Software Center.
  + Removed deprecated uses of GTK_STOCK_*.
  + Removed deprecated uses of GtkAction and GtkActionGroup.
  + Fixed with drag-and-drop behavior, failing with pcmanfm.
  + Fixed selection of multiple pictures with Ctrl and/or Shift.
  + Fixed problem with ref counting for pictures, sets and groups.
  + Fixed memory leak in flicksoup (SoupBuffer was never freed).
  + Raised libsoup minimum version up to 2.34.
  + As usual, other minor improvements, bug fixes and cleanups.
  + Bugs fixed: bgo##693230, bgo#697456, bgo#700005, bgo#703544,
    bgo#704628, bgo#706725, bgo#708231, bgo#720156.
  + Updated translations.
- Exchange gnome-doc-utils-devel for yelp-tools and itstool,
  following upstreams port to new help structure.
- Stop removing -DGTK_DISABLE_DEPRECATED from configure.ac, fixed
  upstream.
- Drop frogr-port-to-gst_1.0.patch, fixed upstream.
- Drop automake BuildRequires and stop passing autoreconf to
  configure, no longer needed since we do not have any patches
  anymore.
* Mon Sep  9 2013 dimstar@opensuse.org
- Remove -DGTK_DISABLE_DEPRECATED from configure.ac in order to
  allow building against Gtk+ 3.9.x.
* Thu Jan 24 2013 zaitor@opensuse.org
- Update to version 0.8:
  + Added support for uploading videos (formats supported by Flickr
    only).
  + Added new 'All' and 'Video' filters to the file chooser dialog.
  + Added support for saving and loading 'projects'.
  + Added new items to the toolbar ('Open' and 'Save' for projects)
  + Ported to GtkApplication and GMenu (both the app menu and menu
    bar).
  + Allow sorting elements in the icon view by size.
  + Don't give up on upload too early and retry some times when
    possible.
  + Report errors better, and more often.
  + Make after-upload operations cancellable, repeatable and
    parallelizable.
  + Properly check and report whether an user is actually connected
    to flickr.
  + Avoid fetching sets/groups/tags when not connected yet to
    Flickr.
  + Renamed the 'Actions' menu to 'Edit' and brought the 'File'
    menu back.
  + Renamed the 'Load Pictures' item to 'Add Pictures'
  + Updated menu item accelerators and shortcuts.
  + Hide title bar when main window is maximized.
  + Migrated from GtkTable to GtkGrid.
  + Raised glib minimum version up to 2.32.
  + Raised gtk+ minimum version up to 3.4.
  + Ported the Mac OS X version from GTK+ 2.24 to to GTK+ 3.6.
  + Created a JHBuild's moduleset to easily build frogr for Mac OS
    X.
  + Stop using gtk-mac-integration, now we have migrated to GMenu.
  + As usual, other minor improvements, bug fixes and cleanups.
  + Bug fixes: bgo#663352, bgo#687741, bgo#675540, bgo#684501,
    bgo#690415, bgo#690416.
  + Updated translations.
- Add pkgconfig(json-glib-1.0) BuildRequires: New dependency.
- Drop preferences-general.png source/hack, fixed upstream.
- Add frogr-port-to-gst_1.0.patch: Port to GStreamer 1.0
  (bgo#693230). Only apply for 12.3 and newer, allowing this
  version still to be built for 12.2.
- Add conditional pkgconfig(gstreamer-1.0) or
  pkgconfig(gstreamer-0.10) BuildRequires, new dependency for
  either the upstream codebase or the Port to GStreamer 1.0 patch
- Add automake BuildRequires and call to autoreconf as
  frogr-port-to-gst_1.0.patch touches the build system.
- Drop the favor_gtk2 conditional construct: Frogr now only
  supports GTK+ 3.0.
- Simplify post/postun scriptlets by removing conditions for
  openSUSE <= 11.3.
* Fri Jun 29 2012 vuntz@opensuse.org
- Manually ship preferences-general.png as source: it's a picture
  from the documentation, missing in the tarball. The fact that
  it's missing creates a broken symlink, that makes the build of
  bundle-lang-gnome-extras fail.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  ends in the main subpackage, instead of the lang subpackage.
* Tue May 22 2012 zaitor@opensuse.org
- Update to version 0.7:
  + Migrated to the new, OAuth-based, authentication system.
    Previous versions of frogr using the old API will be seamlessly
    updated.
  + Import tags from picture's metainformation if present.
  + Allow setting the geolocation information for a picture, if
    available, as extracted from its EXIF data.
  + New tags added are immediately added to the auto-completion
    feature.
  + Allow using a dark theme if available.
  + Show error when loading a picture if bigger than maximum
    allowed size.
  + Some redesign in the menubar and in the 'edit details' dialog.
  + Added keyboard accelerators to menu items.
  + Better integration with GTK+3 (e.g. primary toolbar, dark
    theme).
  + Fix issues in Mac OS X when opening external applications.
  + Other minor improvements, bug fixes and cleanups.
  + Bugs fixed: bgo#656432, bgo#656448, bgo#656466, bgo#656519,
    bgo#656520, bgo#658120.
  + Updated translations.
- Added libgcrypt-devel BuildRequires: new dependency for the
  OAuth-based authentication system.
* Mon Oct  3 2011 vuntz@opensuse.org
- Remove usage of %%mime_database_{post,postun} macros as there is
  no MIME definition installed.
* Fri Aug 19 2011 dimstar@opensuse.org
- Update to version 0.6.1:
  + Fix a big memory leak loading pixbufs in details window.
  + Fixed several mem leaks as reported by valgrind.
  + Fixed segfault if using GTK < 2.24 when using combo boxes
  + Fixed problems authorizing in the Mac version.
  + Bugs fixed: bgo#656519.
* Sat Aug 13 2011 dimstar@opensuse.org
- Update to version 0.6:
  + Support for using the GNOME general proxy settings.
  + Allow setting license type from the details dialog.
  + Open images in default image viewer.
  + Allow removing similar descriptions from multiple pictures.
  + Use better thumbnails for pictures, that is, bigger ones.
  + Redesigned the "edit details" and "preferences" dialogs.
  + Use stock images for several menu items in the main view.
  + Improvements in the authorization process with flaky
    connections.
  + Optimized usage of memory handling because of thumbnails.
  + Fixed segfault when no valid uris are passed via command line.
  + Updated man page to talk about URIs instead of URLs.
  + Avoid potential problems by creating m4 dir upfront.
  + Fixed issues in license headers.
  + Use license-type instead of license property.
  + Fixed frogr.spec file.
  + Use GtkAction for menus in the main view.
  + Added functions to allow setting the license type in flicksoup.
  + Several other minor improvements, small bug fixes and cleanups.
  + Bugs fixed: bgo#644840, bgo#644841, bgo#651230, bgo#651337,
    bgo#651527, bgo#653592, bgo#653860, bgo#653990, bgo#653991,
    bgo#653993, bgo#653994.
  + Updated translations.
- Drop frogr-no-deprecated-GtkBox.patch: fixed upstream.
- Add gnome-doc-utils-devel BuildRequires.
* Mon Jul 18 2011 vuntz@opensuse.org
- Add frogr-no-deprecated-GtkBox.patch to fix build by not using
  deprecated Gtk[HV]Box with GTK+ 3.
* Sat May 28 2011 vuntz@opensuse.org
- Use favor_gtk2 to switch between gtk2 and gtk3 builds, and choose
  between gtk+-2.0 and gtk+-3.0 pkgconfig() BuildRequires.
* Fri May 27 2011 badshah400@gmail.com
- Initial package (version 0.5)
